( cd usr/lib64 ; rm -rf libevent-2.0.so.5 )
( cd usr/lib64 ; ln -sf libevent-2.0.so.5.1.9 libevent-2.0.so.5 )
( cd usr/lib64 ; rm -rf libevent_core-2.0.so.5 )
( cd usr/lib64 ; ln -sf libevent_core-2.0.so.5.1.9 libevent_core-2.0.so.5 )
( cd usr/lib64 ; rm -rf libevent_extra-2.0.so.5 )
( cd usr/lib64 ; ln -sf libevent_extra-2.0.so.5.1.9 libevent_extra-2.0.so.5 )
( cd usr/lib64 ; rm -rf libevent_core.so )
( cd usr/lib64 ; ln -sf libevent_core-2.0.so.5.1.9 libevent_core.so )
( cd usr/lib64 ; rm -rf libevent_openssl-2.0.so.5 )
( cd usr/lib64 ; ln -sf libevent_openssl-2.0.so.5.1.9 libevent_openssl-2.0.so.5 )
( cd usr/lib64 ; rm -rf libevent_openssl.so )
( cd usr/lib64 ; ln -sf libevent_openssl-2.0.so.5.1.9 libevent_openssl.so )
( cd usr/lib64 ; rm -rf libevent.so )
( cd usr/lib64 ; ln -sf libevent-2.0.so.5.1.9 libevent.so )
( cd usr/lib64 ; rm -rf libevent_pthreads.so )
( cd usr/lib64 ; ln -sf libevent_pthreads-2.0.so.5.1.9 libevent_pthreads.so )
( cd usr/lib64 ; rm -rf libevent_pthreads-2.0.so.5 )
( cd usr/lib64 ; ln -sf libevent_pthreads-2.0.so.5.1.9 libevent_pthreads-2.0.so.5 )
( cd usr/lib64 ; rm -rf libevent_extra.so )
( cd usr/lib64 ; ln -sf libevent_extra-2.0.so.5.1.9 libevent_extra.so )
